SystemOrganization addCategory: #ConfigurationOfSciSmalltalk!

Object subclass: #ConfigurationOfSciSmalltalk
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSciSmalltalk'!

!ConfigurationOfSciSmalltalk commentStamp: '<historical>' prior: 0!
A ConfigurationOfSciSmalltalk is a Metacello Configuration to load the packages in the SciSmalltalk project.

More information is available at https://github.com/SergeStinckwich/SciSmalltalk

!

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSciSmalltalk class methodsFor: 'private' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSciSmalltalk class methodsFor: 'private' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSciSmalltalk class methodsFor: 'private' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSciSmalltalk class methodsFor: 'metacello tool support' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSciSmalltalk class methodsFor: 'loading' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSciSmalltalk class methodsFor: 'loading' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSciSmalltalk class methodsFor: 'loading' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSciSmalltalk class methodsFor: 'accessing' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
project

	^self new project! !

!ConfigurationOfSciSmalltalk class methodsFor: 'development support' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSciSmalltalk methodsFor: 'baselines' stamp: 'DanielUber 5/17/2012 14:19'!
baseline100: spec 
        <version: '1.0-baseline'>
        
        spec for: #common do: [
                spec blessing: #baseline.
                spec repository: 'http://ss3.gemstone.com/ss/SciSmalltalk'.    
                spec 
			package: 'Math-All'.
                spec
                        group: 'default' with: #('Core');
                        group: 'Core' with: #('Math-All');
                        group: 'Tests' with: #('Math-All'). ].! !

!ConfigurationOfSciSmalltalk methodsFor: 'symbolic versions' stamp: 'DanielUber 5/20/2012 14:46'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '1.01'.
! !

!ConfigurationOfSciSmalltalk methodsFor: 'accessing' stamp: 'DanielUber 5/16/2012 16:11:19.556'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'DanielUber 5/17/2012 14:17'!
version100: spec 
        <version: '1.0' imports: #('1.0-baseline') >
        
        spec for: #common do: [
                spec blessing: #release.
                spec 
			package: 'Math-All' with: 'Math-All-DanielUber.3'].! !

!ConfigurationOfSciSmalltalk methodsFor: 'versions' stamp: 'DanielUber 5/20/2012 14:43'!
version101: spec 
        <version: '1.01' imports: #('1.0-baseline') >
        
        spec for: #common do: [
                spec blessing: #release.
                spec 
			package: 'Math-All' with: 'Math-All-DanielUber.8'].! !
